var classIMP_1_1statistics_1_1RecursivePartitionalClusteringMetric =
[
    [ "RecursivePartitionalClusteringMetric", "classIMP_1_1statistics_1_1RecursivePartitionalClusteringMetric.html#a0eb7c7bea72016758a63d42ddcd0552a", null ],
    [ "create_full_clustering", "classIMP_1_1statistics_1_1RecursivePartitionalClusteringMetric.html#a298cc8279d3029e200a24ce9fb247942", null ],
    [ "get_distance", "classIMP_1_1statistics_1_1RecursivePartitionalClusteringMetric.html#a1e7a4a9de58876638dfdf942b63b5d75", null ],
    [ "get_number_of_items", "classIMP_1_1statistics_1_1RecursivePartitionalClusteringMetric.html#adf860e1b50428f82bfaff5de5226241a", null ],
    [ "get_type_name", "classIMP_1_1statistics_1_1RecursivePartitionalClusteringMetric.html#ac018cd3f52e2233ed5cfc2305743033a", null ],
    [ "get_version_info", "classIMP_1_1statistics_1_1RecursivePartitionalClusteringMetric.html#ac6f641d694bd964c3b56eb57d704df21", null ]
];